==> korolev-zio_3-1.5.0-M1-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"zio","t":"zio","d":"","k":"static"},
{"l":"korolev/zio.html","n":"korolev.zio","t":"package korolev.zio","d":"korolev/zio","k":"package"},
{"l":"korolev/zio.html","n":"taskEffectInstance","t":"def taskEffectInstance[R](runtime: Runtime[R]): Effect[Task]","d":"korolev/zio","k":"def"},
{"l":"korolev/zio.html","n":"zioEffectInstance","t":"def zioEffectInstance[R, E](runtime: Runtime[R])(liftError: Throwable => E)(unliftError: E => Throwable): Effect[[_] =>> ZIO[R, E, _$1]]","d":"korolev/zio","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"ZioEffect","t":"class ZioEffect[R, E](rts: Runtime[R], liftError: Throwable => E, unliftError: E => Throwable) extends Effect[[_] =>> ZIO[R, E, _$1]]","d":"korolev/zio/ZioEffect","k":"class"},
{"l":"korolev/zio/ZioEffect.html","n":"delay","t":"def delay[A](value: => A): ZIO[R, E, A]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"fail","t":"def fail[A](e: Throwable): ZIO[R, E, A]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"flatMap","t":"def flatMap[A, B](m: ZIO[R, E, A])(f: A => ZIO[R, E, B]): ZIO[R, E, B]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"fork","t":"def fork[A](m: => ZIO[R, E, A])(implicit ec: ExecutionContext): ZIO[R, E, A]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"fromTry","t":"def fromTry[A](value: => Try[A]): ZIO[R, E, A]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"map","t":"def map[A, B](m: ZIO[R, E, A])(f: A => B): ZIO[R, E, B]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"never","t":"def never[T]: ZIO[R, E, T]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"promise","t":"def promise[A](callback: Either[Throwable, A] => Unit => Unit): ZIO[R, E, A]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"promiseF","t":"def promiseF[A](callback: Either[Throwable, A] => Unit => ZIO[R, E, Unit]): ZIO[R, E, A]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"pure","t":"def pure[A](value: A): ZIO[R, E, A]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"recover","t":"def recover[A, AA >: A](m: ZIO[R, E, A])(f: PartialFunction[Throwable, AA]): ZIO[R, E, AA]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"recoverF","t":"def recoverF[A, AA >: A](m: ZIO[R, E, A])(f: PartialFunction[Throwable, ZIO[R, E, AA]]): ZIO[R, E, AA]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"run","t":"def run[A](m: ZIO[R, E, A]): Either[Throwable, A]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"runAsync","t":"def runAsync[A](m: ZIO[R, E, A])(callback: Either[Throwable, A] => Unit): Unit","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"sequence","t":"def sequence[A](in: List[ZIO[R, E, A]]): ZIO[R, E, List[A]]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"start","t":"def start[A](task: => ZIO[R, E, A])(implicit ec: ExecutionContext): ZIO[R, E, Fiber[[_] =>> ZIO[R, E, _$2], A]]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"toFuture","t":"def toFuture[A](m: ZIO[R, E, A]): Future[A]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"unit","t":"def unit: ZIO[R, E, Unit]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"docs/index.html","n":"zio","t":"zio","d":"","k":"static"}];

==> korolev-zio_3-1.16.0-M1-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"zio","t":"zio","d":"","k":"static"},
{"l":"korolev/zio.html","n":"korolev.zio","t":"package korolev.zio","d":"korolev/zio","k":"package"},
{"l":"korolev/zio.html","n":"taskEffectInstance","t":"def taskEffectInstance[R](runtime: Runtime[R]): Effect[Task]","d":"korolev/zio","k":"def"},
{"l":"korolev/zio.html","n":"zioEffectInstance","t":"def zioEffectInstance[R, E](runtime: Runtime[R])(liftError: Throwable => E)(unliftError: E => Throwable): Effect[[_] =>> ZIO[R, E, _$1]]","d":"korolev/zio","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"ZioEffect","t":"class ZioEffect[R, E](rts: Runtime[R], liftError: Throwable => E, unliftError: E => Throwable) extends Effect[[_] =>> ZIO[R, E, _$1]]","d":"korolev/zio/ZioEffect","k":"class"},
{"l":"korolev/zio/ZioEffect.html","n":"blocking","t":"def blocking[T](f: => T)(implicit ec: ExecutionContext): ZIO[R, E, T]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"delay","t":"def delay[A](value: => A): ZIO[R, E, A]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"fail","t":"def fail[A](e: Throwable): ZIO[R, E, A]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"flatMap","t":"def flatMap[A, B](m: ZIO[R, E, A])(f: A => ZIO[R, E, B]): ZIO[R, E, B]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"fork","t":"def fork[A](m: => ZIO[R, E, A])(implicit ec: ExecutionContext): ZIO[R, E, A]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"fromTry","t":"def fromTry[A](value: => Try[A]): ZIO[R, E, A]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"map","t":"def map[A, B](m: ZIO[R, E, A])(f: A => B): ZIO[R, E, B]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"never","t":"def never[T]: ZIO[R, E, T]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"promise","t":"def promise[A](callback: Either[Throwable, A] => Unit => Unit): ZIO[R, E, A]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"promiseF","t":"def promiseF[A](callback: Either[Throwable, A] => Unit => ZIO[R, E, Unit]): ZIO[R, E, A]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"pure","t":"def pure[A](value: A): ZIO[R, E, A]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"recover","t":"def recover[A, AA >: A](m: ZIO[R, E, A])(f: PartialFunction[Throwable, AA]): ZIO[R, E, AA]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"recoverF","t":"def recoverF[A, AA >: A](m: ZIO[R, E, A])(f: PartialFunction[Throwable, ZIO[R, E, AA]]): ZIO[R, E, AA]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"run","t":"def run[A](m: ZIO[R, E, A]): Either[Throwable, A]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"runAsync","t":"def runAsync[A](m: ZIO[R, E, A])(callback: Either[Throwable, A] => Unit): Unit","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"sequence","t":"def sequence[A](in: List[ZIO[R, E, A]]): ZIO[R, E, List[A]]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"start","t":"def start[A](task: => ZIO[R, E, A])(implicit ec: ExecutionContext): ZIO[R, E, Fiber[[_] =>> ZIO[R, E, _$2], A]]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"toFuture","t":"def toFuture[A](m: ZIO[R, E, A]): Future[A]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"korolev/zio/ZioEffect.html","n":"unit","t":"def unit: ZIO[R, E, Unit]","d":"korolev/zio/ZioEffect","k":"def"},
{"l":"docs/index.html","n":"zio","t":"zio","d":"","k":"static"}];
